@@ -20,10 +20,17 @@
 ## Kevin M. Quinn
 ## Harvard University
 ##
+## This software is distributed under the terms of the GNU GENERAL
+## PUBLIC LICENSE Version 2, June 1991.  See the package LICENSE
+## file for more information.
+##
 ## 12/2/2003
 ## Revised to accommodate new spec 7/20/2004
 ## Minor bug fix regarding std.mean 6/25/2004
 ##
+## Copyright (C) 2003-2007 Andrew D. Martin and Kevin M. Quinn
+## Copyright (C) 2007-present Andrew D. Martin, Kevin M. Quinn,
+##    and Jong Hee Park
 ##########################################################################
 
 "MCMCmixfactanal" <-
@@ -36,6 +43,7 @@
            std.mean=TRUE, std.var=TRUE, ... ) {
     
     call <- match.call()
+    echo.name <- NULL
     mt <- terms(x, data=data)
     if (attr(mt, "response") > 0) 
       stop("Response not allowed in formula in MCMCmixfactanal().\n")
@@ -157,7 +165,7 @@
                 }
                 if (ncat[i] == 2){
                   probit.out <- glm(as.factor(X[X[,i]!=-999,i])~1,
-                                    family=binomial(link=probit))
+                                    family=binomial(link="probit"))
                   probit.beta <- coef(probit.out)
                   Lambda[i,j] <- probit.beta[1]
                 }
@@ -261,6 +269,7 @@
     accepts <- matrix(0, K, 1)
 
     # Call the C++ code to do the real work
+    posterior <- NULL
     posterior <- .C("mixfactanalpost",
                     samdata = as.double(sample),
                     samrow = as.integer(nrow(sample)),
